import { z } from "zod";
import { AtlasToolBase } from "./atlasTool.js";
export class CreateFreeClusterTool extends AtlasToolBase {
    constructor() {
        super(...arguments);
        this.name = "atlas-create-free-cluster";
        this.description = "Create a free MongoDB Atlas cluster";
        this.argsShape = {
            projectId: z.string().describe("Atlas project ID to create the cluster in"),
            name: z.string().describe("Name of the cluster"),
            region: z.string().describe("Region of the cluster").default("US_EAST_1"),
        };
    }
    async execute({ projectId, name, region }) {
        this.session.ensureAuthenticated();
        const input = {
            groupId: projectId,
            name,
            clusterType: "REPLICASET",
            replicationSpecs: [
                {
                    zoneName: "Zone 1",
                    regionConfigs: [
                        {
                            providerName: "TENANT",
                            backingProviderName: "AWS",
                            regionName: region,
                            electableSpecs: {
                                instanceSize: "M0",
                            },
                        },
                    ],
                },
            ],
            terminationProtectionEnabled: false,
        };
        await this.session.apiClient.createCluster({
            params: {
                path: {
                    groupId: projectId,
                },
            },
            body: input,
        });
        return {
            content: [{ type: "text", text: `Cluster "${name}" has been created in region "${region}".` }],
        };
    }
}
//# sourceMappingURL=createFreeCluster.js.map