import { z } from "zod";
import { DbOperationArgs, MongoDBToolBase } from "../mongodbTool.js";
export class InsertOneTool extends MongoDBToolBase {
    constructor() {
        super(...arguments);
        this.name = "insert-one";
        this.description = "Insert a document into a MongoDB collection";
        this.argsShape = {
            ...DbOperationArgs,
            document: z
                .object({})
                .passthrough()
                .describe("The document to insert, matching the syntax of the document argument of db.collection.insertOne()"),
        };
        this.operationType = "create";
    }
    async execute({ database, collection, document, }) {
        const provider = await this.ensureConnected();
        const result = await provider.insertOne(database, collection, document);
        return {
            content: [
                {
                    text: `Inserted document with ID \`${result.insertedId.toString()}\` into collection \`${collection}\``,
                    type: "text",
                },
            ],
        };
    }
}
//# sourceMappingURL=insertOne.js.map