import { z } from "zod";
import { DbOperationArgs, MongoDBToolBase } from "../mongodbTool.js";
export const AggregateArgs = {
    pipeline: z.array(z.object({}).passthrough()).describe("An array of aggregation stages to execute"),
    limit: z.number().optional().default(10).describe("The maximum number of documents to return"),
};
export class AggregateTool extends MongoDBToolBase {
    constructor() {
        super(...arguments);
        this.name = "aggregate";
        this.description = "Run an aggregation against a MongoDB collection";
        this.argsShape = {
            ...DbOperationArgs,
            ...AggregateArgs,
        };
        this.operationType = "read";
    }
    async execute({ database, collection, pipeline, }) {
        const provider = await this.ensureConnected();
        const documents = await provider.aggregate(database, collection, pipeline).toArray();
        const content = [
            {
                text: `Found ${documents.length} documents in the collection \`${collection}\`:`,
                type: "text",
            },
            ...documents.map((doc) => {
                return {
                    text: JSON.stringify(doc),
                    type: "text",
                };
            }),
        ];
        return {
            content,
        };
    }
}
//# sourceMappingURL=aggregate.js.map