import { DbOperationArgs, MongoDBToolBase } from "../mongodbTool.js";
import { z } from "zod";
export const CountArgs = {
    query: z
        .object({})
        .passthrough()
        .optional()
        .describe("The query filter to count documents. Matches the syntax of the filter argument of db.collection.count()"),
};
export class CountTool extends MongoDBToolBase {
    constructor() {
        super(...arguments);
        this.name = "count";
        this.description = "Gets the number of documents in a MongoDB collection";
        this.argsShape = {
            ...DbOperationArgs,
            ...CountArgs,
        };
        this.operationType = "metadata";
    }
    async execute({ database, collection, query }) {
        const provider = await this.ensureConnected();
        const count = await provider.count(database, collection, query);
        return {
            content: [
                {
                    text: `Found ${count} documents in the collection \`${collection}\``,
                    type: "text",
                },
            ],
        };
    }
}
//# sourceMappingURL=count.js.map