import logger from "../logger.js";
import { mongoLogId } from "mongodb-log-writer";
export class ToolBase {
    constructor(session) {
        this.session = session;
    }
    register(server) {
        const callback = async (...args) => {
            try {
                // TODO: add telemetry here
                logger.debug(mongoLogId(1000006), "tool", `Executing ${this.name} with args: ${JSON.stringify(args)}`);
                return await this.execute(...args);
            }
            catch (error) {
                logger.error(mongoLogId(1000000), "tool", `Error executing ${this.name}: ${error}`);
                return await this.handleError(error);
            }
        };
        server.tool(this.name, this.description, this.argsShape, callback);
    }
    // This method is intended to be overridden by subclasses to handle errors
    handleError(error) {
        return {
            content: [
                {
                    type: "text",
                    text: `Error running ${this.name}: ${error instanceof Error ? error.message : String(error)}`,
                },
            ],
            isError: true,
        };
    }
}
//# sourceMappingURL=tool.js.map